@@ -1,9 +1,9 @@
 /* Test of select() substitute.
-   Copyright (C) 2008-2022 Free Software Foundation, Inc.
+   Copyright (C) 2008-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -25,10 +25,12 @@
 SIGNATURE_CHECK (select, int, (int, fd_set *, fd_set *, fd_set *,
                                struct timeval *));
 
+#define TEST_PORT 12346
 #include "test-select.h"
 
 int
 main (void)
 {
-  return test_function (select);
+  int result = test_function (select);
+  return (result ? result : test_exit_status);
 }
