@@ -1,5 +1,5 @@
 /* Test the Unicode character type functions.
-   Copyright (C) 2007, 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007, 2009-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,5 +33,5 @@ main ()
   for (; c < 0x110000; c++)
     ASSERT (!PREDICATE (c));
 
-  return 0;
+  return test_exit_status;
 }
