@@ -1,5 +1,5 @@
 /* Test the Unicode character type functions.
-   Copyright (C) 2007-2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -38,5 +38,5 @@ main ()
   ASSERT (uc_is_block (0x2A6D6, &b));
   ASSERT (!uc_is_block (0x2A6D7, &b));
 
-  return 0;
+  return test_exit_status;
 }
