@@ -1,5 +1,5 @@
 /* Next grapheme cluster length test.
-   Copyright (C) 2010-2024 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as published
@@ -95,6 +95,15 @@ main (void)
   test_u16_grapheme_next (2, 'e', ACUTE, 'x', -1);
   test_u16_grapheme_next (2, 'e', ACUTE, 'e', ACUTE, -1);
 
+  /* CR LF handling.  */
+  test_u16_grapheme_next (2, '\r', '\n', 'd', -1);
+
+  /* Emoji modifier / ZWJ sequence. */
+  test_u16_grapheme_next (5, 0x2B50, 0x0305, 0x0347, 0x200D, 0x2600, -1);
+
+  /* Regional indicators. */
+  test_u16_grapheme_next (4, 0xD83C, 0xDDE9, 0xD83C, 0xDDEA, 0xD83C, 0xDDEB, 0xD83C, 0xDDF7, -1);
+
   /* Surrogate pairs. */
   test_u16_grapheme_next (2, 0xd83d, 0xde10, -1); /* 😐: neutral face. */
   test_u16_grapheme_next (3, 0xd83d, 0xde10, GRAVE, -1);
