@@ -1,9 +1,9 @@
 /* Grapheme cluster breaks test.
-   Copyright (C) 2010-2018 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as published
-   by the Free Software Foundation; either version 3 of the License, or
+   by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -50,7 +50,7 @@ test_u8_grapheme_breaks (const char *input, const char *expected)
 
         fprintf (stderr, "   input:");
         for (j = 0; j < n; j++)
-          fprintf (stderr, " %02x", s[j]);
+          fprintf (stderr, " %02X", s[j]);
         putc ('\n', stderr);
 
         fprintf (stderr, "expected:");
@@ -63,6 +63,7 @@ test_u8_grapheme_breaks (const char *input, const char *expected)
           fprintf (stderr, "  %d", breaks[j]);
         putc ('\n', stderr);
 
+        fflush (stderr);
         abort ();
       }
 
@@ -91,5 +92,16 @@ main (void)
   test_u8_grapheme_breaks ("e"ACUTE"x", "#__#");
   test_u8_grapheme_breaks ("e"ACUTE "e"ACUTE, "#__#__");
 
-  return 0;
+  /* CR LF handling.  */
+  test_u8_grapheme_breaks ("a\nb\rc\r\nd", "######_#");
+
+  /* Emoji modifier / ZWJ sequence. */
+  test_u8_grapheme_breaks ("\342\255\220\314\205\315\207\342\200\215\342\230\200",
+                           "#____________");
+
+  /* Regional indicators. */
+  test_u8_grapheme_breaks (".\360\237\207\251\360\237\207\252\360\237\207\253\360\237\207\267.",
+                           "##_______#_______#");
+
+  return test_exit_status;
 }
