@@ -1,5 +1,5 @@
 /* Test of u16_mbsnlen() function.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -64,5 +64,5 @@ main ()
       }
   }
 
-  return 0;
+  return test_exit_status;
 }
